@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR;
 
-our $DATE = '2015-11-24'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-01-23'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 our @Module_Lists = (
     {
@@ -68,6 +68,11 @@ trying to keep startup overhead under 25-50ms). The alternate module I'm using
 now `Log::Any::IfLOG` is a simple wrapper that avoids loading `Log::Any` unless
 some environment variable indicates that user wants logging.
 
+Update [2016-01-23]: I'm sick of the inconvenience that `Log::Any::IfLOG` is
+causing and planning to replace the `Log::Any` module set with something I write
+myself. The replacement will focus on low startup overhead, ability to do
+runtime level changing, and the equivalent of `Log::Any::App`. Stay tuned.
+
 _
                 alternate_modules => ['Log::Any::IfLOG'],
             },
@@ -167,6 +172,50 @@ _
             },
         ],
     },
+
+    {
+        summary => 'Retired modules',
+        description => <<'_',
+
+This is a list of some of the modules which I wrote but have now been retired,
+for various reasons but mostly because they are no longer necessary. I've
+purged/retired more modules than these (mostly failed experiments) but they are
+not worth mentioning here because nobody else seems to have used them.
+
+_
+        entries => [
+            {
+                module => 'Data::Schema',
+                description => <<'_',
+
+Superseded by `Data::Sah` since 2012.
+
+_
+                alternate_modules => ['Data::Sah'],
+            },
+            {
+                module => 'Carp::Always::Dump',
+                description => <<'_',
+
+Superseded by `Devel::Confess`, which can do color (`Carp::Always::Color`),
+dumps (`Carp::Always::Dump`), as well as a few other tricks, all in a single
+package.
+
+_
+                alternate_modules => ['Devel::Confess'],
+            },
+            {
+                module => 'Passwd::Unix::Alt',
+                description => <<'_',
+
+Abandoned this fork of `Passwd::Unix` due to a couple of fundamental issues and
+superseded by `Unix::Passwd::File` which is a clean-slate attempt.
+
+_
+                alternate_modules => ['Unix::Passwd::File'],
+            },
+        ],
+    },
 );
 
 our @Author_Lists = (
@@ -211,41 +260,10 @@ Acme::CPANLists::PERLANCAR - PERLANCAR's CPAN lists
 
 =head1 VERSION
 
-This document describes version 0.08 of Acme::CPANLists::PERLANCAR (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2015-11-24.
+This document describes version 0.09 of Acme::CPANLists::PERLANCAR (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-01-23.
 
 =head1 DESCRIPTION
 
-=head1 SEE ALSO
-
-L<Acme::CPANLists>
-
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANLists-PERLANCAR>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-Acme-CPANLists-PERLANCAR>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANLists-PERLANCAR>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 AUTHOR LISTS
 
 =head2 Test list
@@ -349,6 +367,11 @@ trying to keep startup overhead under 25-50ms). The alternate module I'm using
 now C<Log::Any::IfLOG> is a simple wrapper that avoids loading C<Log::Any> unless
 some environment variable indicates that user wants logging.
 
+Update [2016-01-23]: I'm sick of the inconvenience that C<Log::Any::IfLOG> is
+causing and planning to replace the C<Log::Any> module set with something I write
+myself. The replacement will focus on low startup overhead, ability to do
+runtime level changing, and the equivalent of C<Log::Any::App>. Stay tuned.
+
 
 Alternate modules: L<Log::Any::IfLOG>
 
@@ -438,4 +461,71 @@ command-line.
 
 =back
 
+=head2 Retired modules
+
+This is a list of some of the modules which I wrote but have now been retired,
+for various reasons but mostly because they are no longer necessary. I've
+purged/retired more modules than these (mostly failed experiments) but they are
+not worth mentioning here because nobody else seems to have used them.
+
+
+=over
+
+=item * L<Data::Schema>
+
+Superseded by C<Data::Sah> since 2012.
+
+
+Alternate modules: L<Data::Sah>
+
+=item * L<Carp::Always::Dump>
+
+Superseded by C<Devel::Confess>, which can do color (C<Carp::Always::Color>),
+dumps (C<Carp::Always::Dump>), as well as a few other tricks, all in a single
+package.
+
+
+Alternate modules: L<Devel::Confess>
+
+=item * L<Passwd::Unix::Alt>
+
+Abandoned this fork of C<Passwd::Unix> due to a couple of fundamental issues and
+superseded by C<Unix::Passwd::File> which is a clean-slate attempt.
+
+
+Alternate modules: L<Unix::Passwd::File>
+
+=back
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANLists-PERLANCAR>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Acme-CPANLists-PERLANCAR>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANLists-PERLANCAR>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 SEE ALSO
+
+L<Acme::CPANLists>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by perlancar@cpan.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
